@@ -431,8 +431,6 @@ program gwl_punch
 
 !
 ! init some quantities ...
-!
-  CALL hinit0()
 !
   if(lda_plus_u) then 
     CALL init_ns()
@@ -737,9 +735,6 @@ subroutine read_export (pp_file,kunit,uspp_spsi, ascii, single_file, raw)
        ALLOCATE( sevc(npwx,nbnd), STAT=ierr )
        IF (ierr/=0) CALL errore( ' read_export ',' Unable to allocate SEVC ', ABS(ierr) )
 
-       CALL init_us_1
-       CALL init_at_1
-
        CALL allocate_bec_type (nkb,nbnd,becp)
 
        do ik = 1, nkstot
