@@ -175,7 +175,7 @@ SUBROUTINE ppcg_k( h_psi, s_psi, overlap, precondition, &
   ! Print initial info ...
   IF (print_info >= 1)  THEN
      WRITE(stdout, '("Ethr: ",1pD9.2,", npw: ", I10, ", nbnd: ", I10, " , "   &
-                "maxter: ",I5, ", sbsize:  ", I10,", nsb: ", I10 ,", nact: ", I10, ", trtol: ", 1pD9.2 )')  &
+              & "maxter: ",I5, ", sbsize:  ", I10,", nsb: ", I10 ,", nact: ", I10, ", trtol: ", 1pD9.2 )')  &
                 ethr, npw, nbnd, maxter, sbsize, nsb, nact, trtol
      IF (print_info == 3) THEN
         CALL print_rnrm
@@ -1607,9 +1607,9 @@ nguard = 0 ! 24 ! 50
   !
   IMPLICIT NONE
   !
+  INTEGER, INTENT(IN)      :: kdimx, nact
   COMPLEX(DP), INTENT(OUT) :: array_out( kdimx, nact )
   COMPLEX(DP), INTENT(IN)  :: array_in ( kdimx, * )
-  INTEGER, INTENT(IN)      :: kdimx, nact
   INTEGER, INTENT(IN), OPTIONAL :: act_idx( * )
   LOGICAL, INTENT(IN), OPTIONAL :: bgrp_root_only
   !
