@@ -323,6 +323,7 @@ SUBROUTINE latgen(ibrav,celldm,a1,a2,a3,omega)
      a3(1) = a1(1)
      a3(3) =-a1(3)
   ELSEIF (ibrav == -13) THEN
+     CALL infomsg('latgen','BEWARE: axis for ibrav=-13 changed, see documentation!')
      !
      !     One face centered monoclinic lattice unique axis b
      !
@@ -332,9 +333,9 @@ SUBROUTINE latgen(ibrav,celldm,a1,a2,a3,omega)
      !
      sen = sqrt( 1.d0 - celldm(5) ** 2 )
      a1(1) = 0.5d0 * celldm(1)
-     a1(2) =-a1(1) * celldm(2)
-     a2(1) = a1(1)
-     a2(2) =-a1(2)
+     a1(2) = a1(1) * celldm(2)
+     a2(1) =-a1(1)
+     a2(2) = a1(2)
      a3(1) = celldm(1) * celldm(3) * celldm(5)
      a3(3) = celldm(1) * celldm(3) * sen
      !
@@ -425,8 +426,8 @@ SUBROUTINE at2celldm (ibrav,alat,a1,a2,a3,celldm)
      celldm(3) = abs(a3(3))/celldm(1)
   CASE (91 )
      celldm(1) = sqrt( dot_product (a1,a1) )
-     celldm(2) = abs (a2(2)/a1(1))*2.0_dp/celldm(1)
-     celldm(3) = abs (a3(3)/a1(1))*2.0_dp/celldm(1)
+     celldm(2) = abs (a2(2))*2.0_dp/celldm(1)
+     celldm(3) = abs (a3(3))*2.0_dp/celldm(1)
   CASE (10)
      celldm(1) = abs(a1(1))*2.0_dp
      celldm(2) = abs(a2(2))*2.0_dp/celldm(1)
@@ -479,7 +480,7 @@ SUBROUTINE at2celldm (ibrav,alat,a1,a2,a3,celldm)
   !
 END SUBROUTINE at2celldm
 !
-INTEGER FUNCTION at2ibrav (a1, a2, a3) RESULT (ibrav)
+FUNCTION at2ibrav (a1, a2, a3) RESULT (ibrav)
   !
   !     Returns ibrav from lattice vectors if recognized, 0 otherwise
   !
@@ -488,6 +489,7 @@ INTEGER FUNCTION at2ibrav (a1, a2, a3) RESULT (ibrav)
   REAL(dp), INTENT (in) :: a1(3), a2(3), a3(3)
   REAL(dp) :: v1, v2, v3, cosab, cosac, cosbc
   !
+  INTEGER :: ibrav
   ibrav =0
   !
   v1 = sqrt( dot_product( a1,a1 ) )
