@@ -26,13 +26,6 @@ program fd
 
   USE symm_base
   USE symme
-  USE rap_point_group, ONLY : code_group, nclass, nelem, elem, &
-       which_irr, char_mat, name_rap, name_class, gname, ir_ram
-  USE rap_point_group_so, ONLY : nrap, nelem_so, elem_so, has_e, &
-       which_irr_so, char_mat_so, name_rap_so, name_class_so, d_spin, &
-       name_class_so1
-  USE rap_point_group_is, ONLY : nsym_is, sr_is, ftau_is, d_spin_is, &
-       gname_is, sname_is, code_group_is
   USE fft_base, ONLY : dfftp
 
   implicit none
@@ -72,7 +65,7 @@ program fd
   REAL (dp) :: ft1, ft2, ft3
   REAL (dp) :: d(3,3),rd(3,3),dhex(3,3), dcub(3,3)
   REAL (dp) :: accep=1.0d-5
-  LOGICAL :: nodispsym, noatsym,hex
+  LOGICAL :: nodispsym, noatsym, hex
   LOGICAL, ALLOCATABLE :: move_sl(:,:)
   real(DP), PARAMETER :: sin3 = 0.866025403784438597d0, cos3 = 0.5d0, &
                         msin3 =-0.866025403784438597d0, mcos3 = -0.5d0
@@ -109,8 +102,8 @@ program fd
   CALL mp_bcast( tmp_dir, ionode_id, world_comm )
   CALL mp_bcast( prefix, ionode_id, world_comm )
 
-  !reading the xml file
-  call read_xml_file
+  !reading the xml file - WILL CRASH, input variable needed
+  call read_file_new ( )
 
   if (ionode) then
     write(6,*) '**************************************************'
@@ -184,24 +177,19 @@ program fd
 
     IF (verbose) THEN
      WRITE( stdout, '(36x,"s",24x,"frac. trans.")')
-     nsym_is=0
      DO isym = 1, nsym
         WRITE( stdout, '(/6x,"isym = ",i2,5x,a45/)') isym, sname(isym)
-        IF ( ftau(1,isym).NE.0 .OR. ftau(2,isym).NE.0 .OR. &
-             ftau(3,isym).NE.0) THEN
-           ft1 = at(1,1)*ftau(1,isym)/dfftp%nr1 + at(1,2)*ftau(2,isym)/dfftp%nr2 + &
-                at(1,3)*ftau(3,isym)/dfftp%nr3
-           ft2 = at(2,1)*ftau(1,isym)/dfftp%nr1 + at(2,2)*ftau(2,isym)/dfftp%nr2 + &
-                at(2,3)*ftau(3,isym)/dfftp%nr3
-           ft3 = at(3,1)*ftau(1,isym)/dfftp%nr1 + at(3,2)*ftau(2,isym)/dfftp%nr2 + &
-                at(3,3)*ftau(3,isym)/dfftp%nr3
+        IF ( ft(1,isym)**2 + ft(2,isym)**2 + ft(3,isym)**2 > 1.0d-8 ) THEN
+           ft1 = at(1,1)*ft(1,isym) + at(1,2)*ft(2,isym) + at(1,3)*ft(3,isym)
+           ft2 = at(2,1)*ft(1,isym) + at(2,2)*ft(2,isym) + at(2,3)*ft(3,isym)
+           ft3 = at(3,1)*ft(1,isym) + at(3,2)*ft(2,isym) + at(3,3)*ft(3,isym)
            WRITE( stdout, '(1x,"cryst.",3x,"s(",i2,") = (",3(i6,5x), &
                 &        " )    f =( ",f10.7," )")') &
-                isym, (s(1,ipol,isym),ipol=1,3), DBLE(ftau(1,isym))/DBLE(dfftp%nr1)
+                isym, (s(1,ipol,isym),ipol=1,3), ft(1,isym)
            WRITE( stdout, '(17x," (",3(i6,5x), " )       ( ",f10.7," )")') &
-                (s(2,ipol,isym),ipol=1,3), DBLE(ftau(2,isym))/DBLE(dfftp%nr2)
+                (s(2,ipol,isym),ipol=1,3), ft(2,isym)
            WRITE( stdout, '(17x," (",3(i6,5x), " )       ( ",f10.7," )"/)') &
-                (s(3,ipol,isym),ipol=1,3), DBLE(ftau(3,isym))/DBLE(dfftp%nr3)
+                (s(3,ipol,isym),ipol=1,3), ft(3,isym)
            WRITE( stdout, '(1x,"cart. ",3x,"s(",i2,") = (",3f11.7, &
                 &        " )    f =( ",f10.7," )")') &
                 isym, (sr(1,ipol,isym),ipol=1,3), ft1
