@@ -113,16 +113,12 @@ SUBROUTINE readxmlfile_vasp(iexch,icorr,igcx,igcc,inlc,ierr)
                                    eigts1, eigts2, eigts3, gstart, gshells
   USE fft_base,             ONLY : dfftp, dffts
   USE gvecs,                ONLY : ngms, gcutms
-  USE spin_orb,             ONLY : lspinorb, domag
   USE scf,                  ONLY : rho, rho_core, rhog_core, v
   USE wavefunctions,        ONLY : psic
   USE vlocal,               ONLY : strf
   USE io_files,             ONLY : tmp_dir, prefix, iunpun, nwordwfc, iunwfc
   USE io_global,            ONLY : stdout
   USE noncollin_module,     ONLY : noncolin, npol, nspin_lsda, nspin_mag, nspin_gga
-  USE pw_restart_new,       ONLY :  pw_readschema_file, init_vars_from_schema
-  USE qes_types_module,     ONLY :  output_type, parallel_info_type, general_info_type, input_type
-  USE qes_libs_module,      ONLY :  qes_reset 
   USE io_rho_xml,           ONLY : read_scf
   USE fft_rho,              ONLY : rho_g2r
   USE uspp,                 ONLY : becsum
@@ -131,10 +127,8 @@ SUBROUTINE readxmlfile_vasp(iexch,icorr,igcx,igcc,inlc,ierr)
   USE paw_init,             ONLY : paw_init_onecenter, allocate_paw_internals
   USE control_flags,        ONLY : gamma_only
   USE funct,                ONLY : get_inlc, get_dft_name
-  USE kernel_table,         ONLY : initialize_kernel_table
-  USE esm,                  ONLY : do_comp_esm, esm_init
+  USE vdW_DF,               ONLY : generate_kernel
   USE mp_bands,             ONLY : intra_bgrp_comm, nyfft
-  USE Coul_cut_2D,          ONLY : do_cutoff_2D, cutoff_fact
   USE vasp_read_chgcar,     ONLY : vaspread_rho
   !
   IMPLICIT NONE
@@ -184,14 +178,14 @@ SUBROUTINE readxmlfile_vasp(iexch,icorr,igcx,igcc,inlc,ierr)
                                     vasp_atominfo_obj, vasp_structure_obj)
   CALL errore( 'read_xml_file ', 'problem reading file ' // TRIM( tmp_dir ) //'vasprun.xml', ierr )
   !
-  CALL set_dft_from_indices(iexch, icorr, igcx, igcc, inlc)
+  CALL set_dft_from_indices(iexch, icorr, igcx, igcc, 0, inlc)
   WRITE( stdout, '(5X,"Exchange-correlation      = ", &
         &  " (",I2,3I3,2I2,")")') iexch,icorr,igcx,igcc,inlc,imeta
   !
-  ! ... read the vdw kernel table if needed
+  ! ... generate the vdw kernel table if needed
   !
   IF (inlc > 0 ) THEN
-     call initialize_kernel_table(inlc) 
+     call generate_kernel
   END IF
   !
   !
@@ -765,7 +759,7 @@ END SUBROUTINE vasp_readschema_file
 SUBROUTINE vasp_init_xc(vasp_parameters,vasp_atominfo,iexch,icorr,igcx,igcc,inlc,ierr)
   !---------------------------------------------------------
   USE constants,            ONLY : eps4
-  USE vdW_DF,               ONLY : vdw_type
+  USE vdW_DF,               ONLY : inlc_ => inlc
   IMPLICIT NONE
   !
   TYPE(vasp_parameters_type), INTENT(IN)      :: vasp_parameters
@@ -835,11 +829,11 @@ SUBROUTINE vasp_init_xc(vasp_parameters,vasp_atominfo,iexch,icorr,igcx,igcc,inlc
   !
   IF(vasp_parameters%luse_vdw) THEN
      IF(ABS(vasp_parameters%zab_vdw-(-0.8491))<eps4) THEN
-        vdw_type=1
-        inlc = 1
+        inlc_ = 1
+        inlc  = 1
      ELSEIF(ABS(vasp_parameters%zab_vdw-(-1.887))<eps4) THEN
-        vdw_type=2
-        inlc = 2
+        inlc_ = 2
+        inlc  = 2
      ELSE
         CALL errore ('vasp_init_xc', 'Zab_vdW not implemented', vasp_parameters%zab_vdw)
      END IF
