@@ -9,11 +9,10 @@
 !----------------------------------------------------------------------------
 SUBROUTINE c_bands( iter )
   !----------------------------------------------------------------------------
-  !
-  ! ... Driver routine for Hamiltonian diagonalization routines
-  ! ... It reads the Hamiltonian and an initial guess of the wavefunctions
-  ! ... from a file and computes initialization quantities for the
-  ! ... diagonalization routines.
+  !! Driver routine for the Hamiltonian diagonalization ones.
+  !! It reads the Hamiltonian and an initial guess of the wavefunctions
+  !! from a file and computes initialization quantities for the
+  !! diagonalization routines.
   !
   USE kinds,                ONLY : DP
   USE io_global,            ONLY : stdout
@@ -26,7 +25,7 @@ SUBROUTINE c_bands( iter )
   USE control_flags,        ONLY : ethr, isolve, restart
   USE ldaU,                 ONLY : lda_plus_u, U_projection, wfcU
   USE lsda_mod,             ONLY : current_spin, lsda, isk
-  USE wavefunctions, ONLY : evc
+  USE wavefunctions,        ONLY : evc
   USE bp,                   ONLY : lelfield
   USE mp_pools,             ONLY : npool, kunit, inter_pool_comm
   USE mp,                   ONLY : mp_sum
@@ -34,7 +33,8 @@ SUBROUTINE c_bands( iter )
   !
   IMPLICIT NONE
   !
-  INTEGER, INTENT (in) :: iter
+  INTEGER, INTENT(IN) :: iter
+  !! iteration index
   !
   ! ... local variables
   !
@@ -44,14 +44,13 @@ SUBROUTINE c_bands( iter )
   ! ik : counter on k points
   ! ik_: k-point already done in a previous run
   LOGICAL :: exst
-!------------------------------------------------------------------------
-
+  !
   !
   CALL start_clock( 'c_bands' ); !write (*,*) 'start c_bands' ; FLUSH(6)
   !
   ik_ = 0
   avg_iter = 0.D0
-  IF ( restart ) CALL restart_in_cbands(ik_, ethr, avg_iter, et )
+  IF ( restart ) CALL restart_in_cbands( ik_, ethr, avg_iter, et )
   !
   ! ... If restarting, calculated wavefunctions have to be read from file
   ! ... (not needed for a single k-point: this is done in wfcinit, 
@@ -60,17 +59,17 @@ SUBROUTINE c_bands( iter )
   DO ik = 1, ik_
      IF ( nks > 1 .OR. lelfield ) &
         CALL get_buffer ( evc, nwordwfc, iunwfc, ik )
-  END DO
+  ENDDO
   !
   IF ( isolve == 0 ) THEN
      WRITE( stdout, '(5X,"Davidson diagonalization with overlap")' )
-  ELSE IF ( isolve == 1 ) THEN
+  ELSEIF ( isolve == 1 ) THEN
      WRITE( stdout, '(5X,"CG style diagonalization")')
-  ELSE IF ( isolve == 2 ) THEN
+  ELSEIF ( isolve == 2 ) THEN
      WRITE( stdout, '(5X,"PPCG style diagonalization")')
   ELSE
      CALL errore ( 'c_bands', 'invalid type of diagonalization', isolve)
-  END IF
+  ENDIF
   !
   ! ... For each k point diagonalizes the hamiltonian
   !
@@ -80,7 +79,7 @@ SUBROUTINE c_bands( iter )
      !
      current_k = ik
      IF ( lsda ) current_spin = isk(ik)
-     call g2_kin( ik )
+     CALL g2_kin( ik )
      !
      ! ... More stuff needed by the hamiltonian: nonlocal projectors
      !
@@ -113,14 +112,14 @@ SUBROUTINE c_bands( iter )
      !
      nkdum  = kunit * ( nkstot / kunit / npool )
      !
-     IF (ik .le. nkdum) THEN
+     IF (ik <= nkdum) THEN
         IF (check_stop_now()) THEN
-           CALL save_in_cbands(ik, ethr, avg_iter, et )
+           CALL save_in_cbands( ik, ethr, avg_iter, et )
            RETURN
-        END IF
+        ENDIF
      ENDIF
      !
-  END DO k_loop
+  ENDDO k_loop
   !
   CALL mp_sum( avg_iter, inter_pool_comm )
   avg_iter = avg_iter / nkstot
@@ -138,21 +137,20 @@ END SUBROUTINE c_bands
 !----------------------------------------------------------------------------
 SUBROUTINE diag_bands( iter, ik, avg_iter )
   !----------------------------------------------------------------------------
+  !! Driver routine for diagonalization at each k-point. Types of iterative
+  !! diagonalizations currently in use:
   !
-  ! ... Driver routine for diagonalization at each k-point
-  ! ... Two types of iterative diagonalizations are currently used:
-  ! ... a) Davidson algorithm (all-band)
-  ! ... b) Conjugate Gradient (band-by-band)
-  ! ... b) Projected Preconditioned Conjugate Gradient (block)
-  ! ...
-  ! ... internal procedures :
+  !! * Davidson algorithm (all-band);
+  !! * Conjugate Gradient (band-by-band);
+  !! * Projected Preconditioned Conjugate Gradient (block).
   !
-  ! ... diag_bands_gamma(): optimized algorithms for gamma sampling of the BZ
-  ! ...                    (real Hamiltonian)
-  ! ... diag_bands_k()    : general algorithm for arbitrary BZ sampling
-  ! ...                     (complex Hamiltonian)
-  ! ... test_exit_cond()  : the test on the iterative diagonalization
+  !! Internal procedures:
   !
+  !! * \(\textrm{diag_bands_gamma}\)(): optimized algorithms for gamma sampling
+  !!                                    of the BZ (real Hamiltonian);
+  !! * \(\textrm{diag_bands_k}\)(): general algorithm for arbitrary BZ sampling
+  !!                                (complex Hamiltonian);
+  !! * \(\textrm{test_exit_cond}\)(): the test on the iterative diagonalization.
   !
   USE kinds,                ONLY : DP
   USE buffers,              ONLY : get_buffer
@@ -164,10 +162,10 @@ SUBROUTINE diag_bands( iter, ik, avg_iter )
   USE control_flags,        ONLY : ethr, lscf, max_cg_iter, max_ppcg_iter, isolve, &
                                    gamma_only, use_para_diag
   USE noncollin_module,     ONLY : noncolin, npol
-  USE wavefunctions, ONLY : evc
+  USE wavefunctions,        ONLY : evc
   USE g_psi_mod,            ONLY : h_diag, s_diag
   USE scf,                  ONLY : v_of_0
-  USE bp,                   ONLY : lelfield, evcel, evcelp, evcelm, bec_evcel,&
+  USE bp,                   ONLY : lelfield, evcel, evcelp, evcelm, bec_evcel, &
                                    gdir, l3dstring, efield, efield_cry
   USE becmod,               ONLY : bec_type, becp, calbec, &
                                    allocate_bec_type, deallocate_bec_type
@@ -178,11 +176,16 @@ SUBROUTINE diag_bands( iter, ik, avg_iter )
   !
   IMPLICIT NONE
   !
-  INTEGER, INTENT(IN)  :: iter, ik
+  INTEGER, INTENT(IN) :: iter
+  !! iteration index
+  INTEGER, INTENT(IN) :: ik
+  !! k-point index
+  REAL(KIND=DP), INTENT(INOUT) :: avg_iter
+  !! average number of H*psi products
   !
-  REAL (KIND=DP), INTENT(INOUT) :: avg_iter
+  ! ... local variables
   !
-  REAL (KIND=DP) :: cg_iter, ppcg_iter
+  REAL(KIND=DP) :: cg_iter, ppcg_iter
   ! (weighted) number of iterations in Conjugate-Gradient
   INTEGER :: npw, ig, dav_iter, ntry, notconv
   ! number of iterations in Davidson
@@ -193,24 +196,25 @@ SUBROUTINE diag_bands( iter, ik, avg_iter )
   LOGICAL :: lrot
   ! .TRUE. if the wfc have already be rotated
   !
-  integer, parameter :: sbsize = 5, rrstep = 7 ! block dimensions used in PPCG 
+  INTEGER, PARAMETER :: sbsize = 5, rrstep = 7
+  ! block dimensions used in PPCG 
+  !
+  ! Davidson diagonalization uses these external routines on groups of nvec bands
+  EXTERNAL h_psi, s_psi, g_psi
+  ! subroutine h_psi(npwx,npw,nvec,psi,hpsi)  computes H*psi
+  ! subroutine s_psi(npwx,npw,nvec,psi,spsi)  computes S*psi (if needed)
+  ! subroutine g_psi(npwx,npw,nvec,psi,eig)   computes G*psi -> psi
+  !------------------------------------------------------------------------
+  ! CG diagonalization uses these external routines on a single band
+  EXTERNAL hs_1psi, s_1psi
+  ! subroutine hs_1psi(npwx,npw,psi,hpsi,spsi)  computes H*psi and S*psi
+  ! subroutine s_1psi(npwx,npw,psi,spsi)        computes S*psi (if needed)
+  ! In addition to the above ithe initial wfc rotation uses h_psi, and s_psi
+  !------------------------------------------------------------------------
+  ! PPCG diagonalization uses these external routines on groups of bands
+  ! subroutine h_psi(npwx,npw,nvec,psi,hpsi)  computes H*psi
+  ! subroutine s_psi(npwx,npw,nvec,psi,spsi)  computes S*psi (if needed)
   !
-! Davidson diagonalization uses these external routines on groups of nvec bands
-  external h_psi, s_psi, g_psi
-! subroutine h_psi(npwx,npw,nvec,psi,hpsi)  computes H*psi
-! subroutine s_psi(npwx,npw,nvec,psi,spsi)  computes S*psi (if needed)
-! subroutine g_psi(npwx,npw,nvec,psi,eig)   computes G*psi -> psi
-!------------------------------------------------------------------------
-! CG diagonalization uses these external routines on a single band
-   external hs_1psi, s_1psi
-!  subroutine hs_1psi(npwx,npw,psi,hpsi,spsi)  computes H*psi and S*psi
-!  subroutine s_1psi(npwx,npw,psi,spsi)        computes S*psi (if needed)
-! In addition to the above ithe initial wfc rotation uses h_psi, and s_psi
-!------------------------------------------------------------------------
-! PPCG diagonalization uses these external routines on groups of bands
-! subroutine h_psi(npwx,npw,nvec,psi,hpsi)  computes H*psi
-! subroutine s_psi(npwx,npw,nvec,psi,spsi)  computes S*psi (if needed)
-
   ALLOCATE( h_diag( npwx, npol ), STAT=ierr )
   IF( ierr /= 0 ) &
      CALL errore( ' diag_bands ', ' cannot allocate h_diag ', ABS(ierr) )
@@ -226,7 +230,7 @@ SUBROUTINE diag_bands( iter, ik, avg_iter )
   !
   ! ... allocate space for <beta_i|psi_j> - used in h_psi and s_psi
   !
-  CALL allocate_bec_type ( nkb, nbnd, becp, intra_bgrp_comm )
+  CALL allocate_bec_type( nkb, nbnd, becp, intra_bgrp_comm )
   !
   npw = ngk(ik)
   IF ( gamma_only ) THEN
@@ -237,11 +241,11 @@ SUBROUTINE diag_bands( iter, ik, avg_iter )
      !
      CALL diag_bands_k()
      !
-  END IF
+  ENDIF
   !
   ! ... deallocate work space
   !
-  CALL deallocate_bec_type ( becp )
+  CALL deallocate_bec_type( becp )
   DEALLOCATE( s_diag )
   DEALLOCATE( h_diag )
   !
@@ -250,16 +254,16 @@ SUBROUTINE diag_bands( iter, ik, avg_iter )
      CALL errore( 'c_bands', &
           & 'too many bands are not converged', 1 )
      !
-  ELSE IF ( notconv > 0 ) THEN
+  ELSEIF ( notconv > 0 ) THEN
      !
      WRITE( stdout, '(5X,"c_bands: ",I2, &
                &   " eigenvalues not converged")' ) notconv
      !
-  END IF
+  ENDIF
   !
   RETURN
   !
-CONTAINS
+ CONTAINS
   !
   ! ... internal procedures
   !
@@ -291,11 +295,11 @@ CONTAINS
           !
           IF ( .NOT. lrot ) THEN
              !
-             CALL rotate_wfc ( npwx, npw, nbnd, gstart, nbnd, evc, npol, okvan, evc, et(1,ik) )
+             CALL rotate_wfc( npwx, npw, nbnd, gstart, nbnd, evc, npol, okvan, evc, et(1,ik) )
              !
              avg_iter = avg_iter + 1.D0
              !
-          END IF
+          ENDIF
           !
           IF ( isolve == 1 ) THEN
              CALL rcgdiagg( hs_1psi, s_1psi, h_diag, &
@@ -307,11 +311,11 @@ CONTAINS
           ELSE
              CALL ppcg_gamma( h_psi, s_psi, okvan, h_diag, &
                          npwx, npw, nbnd, evc, et(1,ik), btype(1,ik), &
-                         0.1d0*ethr, max_ppcg_iter, notconv, ppcg_iter, sbsize , rrstep, iter  )
+                         0.1d0*ethr, max_ppcg_iter, notconv, ppcg_iter, sbsize , rrstep, iter )
              !
              avg_iter = avg_iter + ppcg_iter
              !
-          END IF
+          ENDIF
           !
           !
           ntry = ntry + 1
@@ -320,7 +324,7 @@ CONTAINS
           !
           IF ( test_exit_cond() ) EXIT  CG_loop
           !
-       END DO CG_loop
+       ENDDO CG_loop
        !
     ELSE
        !
@@ -345,13 +349,15 @@ CONTAINS
 !             ! make sure that all processors have the same wfc
              CALL pregterg( h_psi, s_psi, okvan, g_psi, &
                          npw, npwx, nbnd, nbndx, evc, ethr, &
-                         et(1,ik), btype(1,ik), notconv, lrot, dav_iter ) !    BEWARE gstart has been removed from call 
+                         et(1,ik), btype(1,ik), notconv, lrot, dav_iter )
+                                   !    BEWARE gstart has been removed from call 
              !
           ELSE
              !
              CALL regterg (  h_psi, s_psi, okvan, g_psi, &
                          npw, npwx, nbnd, nbndx, evc, ethr, &
-                         et(1,ik), btype(1,ik), notconv, lrot, dav_iter ) !    BEWARE gstart has been removed from call
+                         et(1,ik), btype(1,ik), notconv, lrot, dav_iter )
+                                   !    BEWARE gstart has been removed from call
           ENDIF
           !
           avg_iter = avg_iter + dav_iter
@@ -362,9 +368,10 @@ CONTAINS
           !
           IF ( test_exit_cond() ) EXIT  david_loop
           !
-       END DO david_loop
+       ENDDO david_loop
        !
-    END IF
+    ENDIF
+    !
     !
     RETURN
     !
@@ -373,16 +380,15 @@ CONTAINS
   !-----------------------------------------------------------------------
   SUBROUTINE diag_bands_k()
     !-----------------------------------------------------------------------
-    !
-    ! ... Complex Hamiltonian diagonalization
+    !! Complex Hamiltonian diagonalization.
     !
     IMPLICIT NONE
     !
-    ! ... here the local variables
+    ! ... local variables
     !
     INTEGER :: ipol
-    REAL(dp) :: eps=0.000001d0
-    !  --- Define a small number ---
+    REAL(DP) :: eps=0.000001d0
+    ! --- Define a small number ---
     !
     !write (*,*) ' enter diag_bands_k'; FLUSH(6)
     IF ( lelfield ) THEN
@@ -393,28 +399,27 @@ CONTAINS
        !
        !... read projectors from disk
        !
-       if(.not.l3dstring .and. ABS(efield)>eps ) then
+       IF (.NOT.l3dstring .AND. ABS(efield)>eps ) THEN
           CALL get_buffer (evcelm(:,:,gdir), nwordwfc, iunefieldm, ik+(gdir-1)*nks)
           CALL get_buffer (evcelp(:,:,gdir), nwordwfc, iunefieldp, ik+(gdir-1)*nks)
-       else
-          do ipol=1,3
-             if(ABS(efield_cry(ipol))>eps) then
-                CALL get_buffer (evcelm(:,:,ipol), nwordwfc, iunefieldm, ik+(ipol-1)*nks)
-                CALL get_buffer (evcelp(:,:,ipol), nwordwfc, iunefieldp, ik+(ipol-1)*nks)
-             endif
-          enddo
-       endif
+       ELSE
+          DO ipol = 1, 3
+             IF ( ABS(efield_cry(ipol))>eps ) THEN
+                CALL get_buffer( evcelm(:,:,ipol), nwordwfc, iunefieldm, ik+(ipol-1)*nks )
+                CALL get_buffer( evcelp(:,:,ipol), nwordwfc, iunefieldp, ik+(ipol-1)*nks )
+             ENDIF
+          ENDDO
+       ENDIF
        !
        IF ( okvan ) THEN
           !
-          call allocate_bec_type(nkb,nbnd,bec_evcel)
-          
+          CALL allocate_bec_type( nkb, nbnd, bec_evcel )
           !
-          CALL calbec(npw, vkb, evcel, bec_evcel)
+          CALL calbec( npw, vkb, evcel, bec_evcel )
           !
        ENDIF
        !
-    END IF
+    ENDIF
     !
     !write (*,*) ' current isolve value ( 0 Davidson, 1 CG, 2 PPCG)', isolve; FLUSH(6)
     IF ( isolve == 1 .OR. isolve == 2) THEN
@@ -440,11 +445,11 @@ CONTAINS
           !
           IF ( .NOT. lrot ) THEN
              !
-             CALL rotate_wfc ( npwx, npw, nbnd, gstart, nbnd, evc, npol, okvan, evc, et(1,ik) )
+             CALL rotate_wfc( npwx, npw, nbnd, gstart, nbnd, evc, npol, okvan, evc, et(1,ik) )
              !
              avg_iter = avg_iter + 1.D0
              !
-          END IF
+          ENDIF
           !
           IF ( isolve == 1) then
              CALL ccgdiagg( hs_1psi, s_1psi, h_diag, &
@@ -454,21 +459,21 @@ CONTAINS
              avg_iter = avg_iter + cg_iter
              !
           ELSE
-! BEWARE npol should be added to the arguments
+             ! BEWARE npol should be added to the arguments
              CALL ppcg_k( h_psi, s_psi, okvan, h_diag, &
                          npwx, npw, nbnd, npol, evc, et(1,ik), btype(1,ik), &
-                         0.1d0*ethr, max_ppcg_iter, notconv, ppcg_iter, sbsize , rrstep, iter)
+                         0.1d0*ethr, max_ppcg_iter, notconv, ppcg_iter, sbsize , rrstep, iter )
              !
              avg_iter = avg_iter + ppcg_iter
              !
-          END IF
+          ENDIF
           ntry = ntry + 1
           !
           ! ... exit condition
           !
           IF ( test_exit_cond() ) EXIT  CG_loop
           !
-       END DO CG_loop
+       ENDDO CG_loop
        !
     ELSE
        !
@@ -482,7 +487,7 @@ CONTAINS
           !
           h_diag(1:npw, ipol) = g2kin(1:npw) + v_of_0
           !
-       END DO
+       ENDDO
        !
        CALL usnldiag( npw, h_diag, s_diag )
        !
@@ -492,7 +497,7 @@ CONTAINS
           !
           lrot = ( iter == 1 )
           !
-          IF ( use_para_diag ) then
+          IF ( use_para_diag ) THEN
              !
              CALL pcegterg( h_psi, s_psi, okvan, g_psi, &
                             npw, npwx, nbnd, nbndx, npol, evc, ethr, &
@@ -500,10 +505,10 @@ CONTAINS
              !
           ELSE
              !
-             CALL cegterg ( h_psi, s_psi, okvan, g_psi, &
-                            npw, npwx, nbnd, nbndx, npol, evc, ethr, &
-                            et(1,ik), btype(1,ik), notconv, lrot, dav_iter )
-          END IF
+             CALL cegterg( h_psi, s_psi, okvan, g_psi, &
+                           npw, npwx, nbnd, nbndx, npol, evc, ethr, &
+                           et(1,ik), btype(1,ik), notconv, lrot, dav_iter )
+          ENDIF
           !
           avg_iter = avg_iter + dav_iter
           !
@@ -517,11 +522,11 @@ CONTAINS
           !
           IF ( test_exit_cond() ) EXIT david_loop
           !
-       END DO david_loop
+       ENDDO david_loop
        !
-    END IF
+    ENDIF
     !
-    IF ( lelfield .AND. okvan ) call deallocate_bec_type( bec_evcel) 
+    IF ( lelfield .AND. okvan ) CALL deallocate_bec_type( bec_evcel )
     !
     RETURN
     !
@@ -530,9 +535,8 @@ CONTAINS
   !-----------------------------------------------------------------------
   FUNCTION test_exit_cond()
     !-----------------------------------------------------------------------
-    !
-    ! ... this logical function is .TRUE. when iterative diagonalization
-    ! ... is converged
+    !! This logical function is .TRUE. when iterative diagonalization
+    !! is converged.
     !
     IMPLICIT NONE
     !
@@ -548,10 +552,9 @@ CONTAINS
 END SUBROUTINE diag_bands
 !
 !----------------------------------------------------------------------------
-SUBROUTINE c_bands_efield ( iter )
+SUBROUTINE c_bands_efield( iter )
   !----------------------------------------------------------------------------
-  !
-  ! ... Driver routine for Hamiltonian diagonalization under an electric field
+  !! Driver routine for Hamiltonian diagonalization under an electric field.
   !
   USE noncollin_module,     ONLY : noncolin, npol
   USE kinds,                ONLY : DP
@@ -564,7 +567,10 @@ SUBROUTINE c_bands_efield ( iter )
   !
   IMPLICIT NONE
   !
-  INTEGER, INTENT (in) :: iter
+  INTEGER, INTENT(IN) :: iter
+  !! iteration index
+  !
+  ! ... local variables
   !
   INTEGER :: inberry, ipol, ierr
   !
@@ -587,18 +593,18 @@ SUBROUTINE c_bands_efield ( iter )
      !...set up electric field hermitean operator
      !
      FLUSH(stdout)
-     if(.not.l3dstring) then
+     IF (.NOT.l3dstring) THEN
         CALL h_epsi_her_set (gdir, efield)
-     else
-        do ipol=1,3
+     ELSE
+        DO ipol=1,3
            CALL h_epsi_her_set(ipol, efield_cry(ipol))
-        enddo
-     endif
+        ENDDO
+     ENDIF
      FLUSH(stdout)
      !
      CALL c_bands( iter )
      !
-  END DO
+  ENDDO
   !
   DEALLOCATE( fact_hepsi )
   DEALLOCATE( evcelp )
@@ -609,11 +615,11 @@ SUBROUTINE c_bands_efield ( iter )
   !
 END SUBROUTINE c_bands_efield
 !
+!------------------------------------------------------------------------------
 SUBROUTINE c_bands_nscf( )
   !----------------------------------------------------------------------------
-  !
-  ! ... Driver routine for Hamiltonian diagonalization routines
-  ! ... specialized to non-self-consistent calculations (no electric field)
+  !! Driver routine for Hamiltonian diagonalization routines
+  !! specialized to non-self-consistent calculations (no electric field).
   !
   USE kinds,                ONLY : DP
   USE io_global,            ONLY : stdout
@@ -627,13 +633,15 @@ SUBROUTINE c_bands_nscf( )
   USE control_flags,        ONLY : ethr, restart, isolve, io_level, iverbosity
   USE ldaU,                 ONLY : lda_plus_u, U_projection, wfcU
   USE lsda_mod,             ONLY : current_spin, lsda, isk
-  USE wavefunctions, ONLY : evc
+  USE wavefunctions,        ONLY : evc
   USE mp_pools,             ONLY : npool, kunit, inter_pool_comm
   USE mp,                   ONLY : mp_sum
   USE check_stop,           ONLY : check_stop_now
   !
   IMPLICIT NONE
   !
+  ! ... local variables
+  !
   REAL(DP) :: avg_iter, ethr_
   ! average number of H*psi products
   INTEGER :: ik_, ik, nkdum, ios
@@ -643,27 +651,28 @@ SUBROUTINE c_bands_nscf( )
   !
   REAL(DP), EXTERNAL :: get_clock
   !
+  !
   CALL start_clock( 'c_bands' )
   !
   ik_ = 0
   avg_iter = 0.D0
-  IF ( restart ) CALL restart_in_cbands(ik_, ethr, avg_iter, et )
+  IF ( restart ) CALL restart_in_cbands( ik_, ethr, avg_iter, et )
   !
   ! ... If restarting, calculated wavefunctions have to be read from file
   !
   DO ik = 1, ik_
-     CALL get_buffer ( evc, nwordwfc, iunwfc, ik )
-  END DO
+     CALL get_buffer( evc, nwordwfc, iunwfc, ik )
+  ENDDO
   !
   IF ( isolve == 0 ) THEN
      WRITE( stdout, '(5X,"Davidson diagonalization with overlap")' )
-  ELSE IF ( isolve == 1 ) THEN
-     WRITE( stdout, '(5X,"CG style diagonalization")')
-  ELSE IF ( isolve == 2 ) THEN
-     WRITE( stdout, '(5X,"PPCG style diagonalization")')
+  ELSEIF ( isolve == 1 ) THEN
+     WRITE( stdout, '(5X,"CG style diagonalization")' )
+  ELSEIF ( isolve == 2 ) THEN
+     WRITE( stdout, '(5X,"PPCG style diagonalization")' )
   ELSE
-     CALL errore ( 'c_bands', 'invalid type of diagonalization', isolve)
-  END IF
+     CALL errore ( 'c_bands', 'invalid type of diagonalization', isolve )
+  ENDIF
   !
   ! ... For each k point (except those already calculated if restarting)
   ! ... diagonalizes the hamiltonian
@@ -674,7 +683,7 @@ SUBROUTINE c_bands_nscf( )
      !
      current_k = ik
      IF ( lsda ) current_spin = isk(ik)
-     call g2_kin( ik )
+     CALL g2_kin( ik )
      ! 
      ! ... More stuff needed by the hamiltonian: nonlocal projectors
      !
@@ -683,44 +692,49 @@ SUBROUTINE c_bands_nscf( )
      ! ... Needed for LDA+U
      !
      IF ( nks > 1 .AND. lda_plus_u .AND. (U_projection .NE. 'pseudo') ) &
-          CALL get_buffer ( wfcU, nwordwfcU, iunhub, ik )
+          CALL get_buffer( wfcU, nwordwfcU, iunhub, ik )
      !
      ! ... calculate starting  wavefunctions
      !
-     IF ( iverbosity > 0 ) WRITE( stdout, 9001 ) ik
+     IF ( iverbosity > 0 .AND. npool == 1 ) THEN
+        WRITE( stdout, 9001 ) ik, nks
+     ELSEIF ( iverbosity > 0 .AND. npool > 1 ) THEN
+        WRITE( stdout, 9002 ) ik, nks
+     ENDIF
      !
      IF ( TRIM(starting_wfc) == 'file' ) THEN
         !
-        CALL get_buffer ( evc, nwordwfc, iunwfc, ik )
+        CALL get_buffer( evc, nwordwfc, iunwfc, ik )
         !
      ELSE
         !
-        CALL init_wfc ( ik )
+        CALL init_wfc( ik )
         !
-     END IF
+     ENDIF
      !
      ! ... diagonalization of bands for k-point ik
      !
-     call diag_bands ( 1, ik, avg_iter )
+     CALL diag_bands( 1, ik, avg_iter )
      !
      ! ... save wave-functions (unless disabled in input)
      !
-     IF ( io_level > -1 ) CALL save_buffer ( evc, nwordwfc, iunwfc, ik )
+     IF ( io_level > -1 ) CALL save_buffer( evc, nwordwfc, iunwfc, ik )
      !
      ! ... beware: with pools, if the number of k-points on different
      ! ... pools differs, make sure that all processors are still in
      ! ... the loop on k-points before checking for stop condition
      !
      nkdum  = kunit * ( nkstot / kunit / npool )
-     IF (ik .le. nkdum) THEN
+     IF (ik <= nkdum) THEN
         !
         ! ... stop requested by user: save restart information,
         ! ... save wavefunctions to file
         !
-        IF (check_stop_now()) THEN
-           CALL save_in_cbands(ik, ethr, avg_iter, et )
+        IF ( check_stop_now() ) THEN
+           CALL save_in_cbands( ik, ethr, avg_iter, et )
            RETURN
-        END IF
+        ENDIF
+        !
      ENDIF
      !
      ! report about timing
@@ -730,7 +744,7 @@ SUBROUTINE c_bands_nscf( )
         FLUSH( stdout )
      ENDIF
      !
-  END DO k_loop
+  ENDDO k_loop
   !
   CALL mp_sum( avg_iter, inter_pool_comm )
   avg_iter = avg_iter / nkstot
@@ -744,7 +758,8 @@ SUBROUTINE c_bands_nscf( )
   !
   ! formats
   !
-9001 FORMAT(/'     Computing kpt #: ',I5 )
+9002 FORMAT(/'     Computing kpt #: ',I5, '  of ',I5,' on this pool' )
+9001 FORMAT(/'     Computing kpt #: ',I5, '  of ',I5 )
 9000 FORMAT( '     total cpu time spent up to now is ',F10.1,' secs' )
   !
 END SUBROUTINE c_bands_nscf
