@@ -60,7 +60,6 @@
                                 gate, zgate, relaxz, block, block_1, block_2, block_height, real_space
 !
   USE fixed_occ,         ONLY:  f_inp               
-                                
 !
   USE kinds,             ONLY:   DP
   USE parameters,        ONLY:   ntypx
@@ -73,7 +72,7 @@
   USE control_flags,     ONLY:   cf_nstep => nstep 
   USE qes_types_module
   USE qes_libs_module
-  USE qexsd_module,      ONLY: qexsd_init_atomic_species, qexsd_init_atomic_structure, qexsd_init_dft, &
+  USE qexsd_init,        ONLY: qexsd_init_atomic_species, qexsd_init_atomic_structure, qexsd_init_dft, &
                                qexsd_init_hybrid, qexsd_init_vdw, qexsd_init_dftU
   USE qexsd_input  
   IMPLICIT NONE
@@ -92,6 +91,8 @@
   INTEGER,EXTERNAL                         ::   set_hubbard_l
   INTEGER                                  ::   lung,l 
   CHARACTER,EXTERNAL                       ::   capital
+  CHARACTER(LEN=8),  EXTERNAL              ::   schema_smearing
+  CHARACTER(LEN=8)                         ::   smearing_loc
   CHARACTER(len=20)                        ::   dft_shortname
   CHARACTER(len=25)                        ::   dft_longname
   CHARACTER(LEN=80),TARGET                 ::  vdw_corr_, vdw_nonlocc_
@@ -252,6 +253,9 @@
                 dftd3_threebody_ = dftd3_threebody
                 dftd3_threebody_pt => dftd3_threebody_
         END SELECT
+     ELSE
+        vdw_corr_ = 'none'
+        vdw_corr_pointer => vdw_corr_
      END IF
      IF (dft_is_nonlocc) THEN
          vdw_nonlocc_ = TRIM(get_nonlocc_name())
@@ -343,20 +347,22 @@
      nbnd_tg = nbnd 
      nbnd_pt => nbnd_tg
   END IF 
+  smearing_loc = schema_smearing(smearing)
   IF (tf_inp) THEN
      SELECT CASE (ip_nspin) 
         CASE (2)  
-           CALL qexsd_init_bands(obj%bands, nbnd_pt, smearing, degauss, ip_occupations, tot_charge, ip_nspin, &
-                                          input_occupations=f_inp(:,1),input_occupations_minority=f_inp(:,2))
+           CALL qexsd_init_bands(obj%bands, nbnd_pt, smearing_loc, degauss/e2, &
+                ip_occupations, tot_charge, ip_nspin, &
+                input_occupations=f_inp(:,1),input_occupations_minority=f_inp(:,2))
         CASE default
-           CALL qexsd_init_bands(obj%bands, nbnd_pt, smearing, degauss, ip_occupations, tot_charge, ip_nspin, &
-                                                                                input_occupations=f_inp(:,1) )
+           CALL qexsd_init_bands(obj%bands, nbnd_pt, smearing_loc, degauss/e2, &
+                ip_occupations, tot_charge, ip_nspin, input_occupations=f_inp(:,1) )
      END SELECT    
   ELSE 
      IF ( tot_magnetization .LT. 0 ) THEN 
-        CALL qexsd_init_bands(obj%bands, nbnd_pt, smearing, degauss, ip_occupations, tot_charge, ip_nspin)
+        CALL qexsd_init_bands(obj%bands, nbnd_pt, smearing_loc, degauss/e2, ip_occupations, tot_charge, ip_nspin)
      ELSE
-        CALL qexsd_init_bands(obj%bands, nbnd_pt, smearing, degauss, ip_occupations, tot_charge, ip_nspin, &
+        CALL qexsd_init_bands(obj%bands, nbnd_pt, smearing_loc, degauss/e2, ip_occupations, tot_charge, ip_nspin, &
                               TOT_MAG  = tot_magnetization)
      END IF
   END IF 
