@@ -15,7 +15,7 @@ subroutine stres_nonloc_dft( rho, rho_core, nspin, sigma_nonloc_dft )
   use funct,            ONLY : get_igcc, get_inlc 
   USE mp,               ONLY : mp_sum
   USE fft_base,         ONLY : dfftp
-  USE vdW_DF,           ONLY : stress_vdW_DF
+  USE vdW_DF,           ONLY : vdW_DF_stress
   USE rVV10,            ONLY : stress_rVV10
   USE io_global,        ONLY : stdout
   !
@@ -31,10 +31,9 @@ subroutine stres_nonloc_dft( rho, rho_core, nspin, sigma_nonloc_dft )
   sigma_nonloc_dft(:,:) = 0.d0
   inlc = get_inlc()
 
-  if ( inlc==1 .or. inlc==2 .or. inlc==4 .or. inlc==5 .or. inlc==6 ) then
-     CALL stress_vdW_DF(rho, rho_core, nspin, sigma_nonloc_dft)
+  if ( inlc==1 .or. inlc==2 ) then
+     CALL vdW_DF_stress(rho, rho_core, nspin, sigma_nonloc_dft)
   elseif ( inlc == 3 ) then
-     if ( nspin>2 ) call errore ('stress_rVV10', 'rVV10 stress not implemented for nspin > 2',1)
      CALL stress_rVV10(rho, rho_core, nspin, sigma_nonloc_dft)
   end if
 
