@@ -1,5 +1,5 @@
 !
-! Copyright (C) 2001-2016 Quantum ESPRESSO group
+! Copyright (C) 2001-2019 Quantum ESPRESSO group
 ! This file is distributed under the terms of the
 ! GNU General Public License. See the file `License'
 ! in the root directory of the present distribution,
@@ -295,10 +295,8 @@ SUBROUTINE lr_apply_liouvillian( evc1, evc1_new, interaction )
   ! interaction=.true.:  S^{-1} P_c^+(k) { (H(k)-E(k)*S) * evc1(k) + dV_HXC * revc0(k) } 
   !
   DO ik = 1, nks
-     !
-     CALL lr_sm1_psi (.FALSE., ik, npwx, ngk(ik), nbnd, &
+     CALL lr_sm1_psi(ik, npwx, ngk(ik), nbnd, &
                        & sevc1_new(1,1,ik), evc1_new(1,1,ik))
-     ! 
   ENDDO
   !
   IF (allocated(dvrs)) DEALLOCATE(dvrs)
