@@ -30,7 +30,7 @@ SUBROUTINE lr_readin
   USE io_global,           ONLY : ionode, ionode_id, stdout
   USE klist,               ONLY : nks, wk, nelec, lgauss, ltetra
   USE fixed_occ,           ONLY : tfixed_occ
-  USE input_parameters,    ONLY : degauss, nosym, wfcdir, outdir
+  USE symm_base,           ONLY : nosym
   USE check_stop,          ONLY : max_seconds
   USE realus,              ONLY : real_space, init_realspace_vars, generate_qpointlist, &
                                   betapointlist
@@ -48,13 +48,13 @@ SUBROUTINE lr_readin
   USE esm,                 ONLY : do_comp_esm
   USE qpoint,              ONLY : xq
   USE io_rho_xml,          ONLY : write_scf
-  USE noncollin_module,    ONLY : noncolin
   USE mp_bands,            ONLY : ntask_groups
   USE constants,           ONLY : eps4
   USE control_lr,          ONLY : lrpa
 
   IMPLICIT NONE
   !
+  CHARACTER(LEN=256) :: wfcdir = 'undefined', outdir
   CHARACTER(LEN=256), EXTERNAL :: trimcheck
   !
   CHARACTER(LEN=256) :: beta_gamma_z_prefix
@@ -326,7 +326,7 @@ SUBROUTINE lr_readin
   ! read_file -> init_igk.
   ! EELS: the variables igk_k and ngk will be re-set up later (because there
   ! will be not only poins k but also points k+q) through the path:
-  ! lr_run_nscf -> init_run -> hinit0 -> init_igk
+  ! lr_run_nscf -> init_run -> allocate_wfc_k -> init_igk
   !
   CALL read_file()
   !
@@ -383,24 +383,6 @@ SUBROUTINE lr_readin
   ! I. Timrov: this was already done in read_file.
   current_spin = 1
   !
-  ! I. Timrov: The routine init_us_1 was already called in read_file above.
-  CALL init_us_1 ( )
-  !
-  ! I. Timrov: The routine newd was already called in read_file above.
-  !
-  CALL newd() !OBM: this is for the ground-state charge density
-  !
-  IF (tqr .AND. .NOT.eels) CALL generate_qpointlist()
-  !
-  IF ( real_space .AND. .NOT.eels) THEN
-     !
-     WRITE(stdout,'(/5x,"Real space implementation V.1 D190908",1x)')
-     ! OBM - correct parellism issues
-     CALL init_realspace_vars()
-     CALL betapointlist()
-     WRITE(stdout,'(5X,"Real space initialisation completed")')
-  ENDIF
-  !
   ! Now put the potential calculated in read_file into the correct place
   ! and deallocate the redundant associated variables.
   ! Set the total local potential vrs on the smooth mesh
@@ -456,6 +438,11 @@ CONTAINS
            & CALL errore ('lr_readin', &
            & 'projection is possible only in charge response mode 1', 1 )
        !
+       IF (gamma_only) THEN
+          nosym=.true.
+          WRITE(stdout,*) "Symmetries are disabled for the gamma_only case"
+       ENDIF
+       !
     ENDIF
     !
     !  Meta-DFT currently not supported by TDDFPT
@@ -534,7 +521,6 @@ CONTAINS
     !
     IF (eels) THEN
        !
-       IF (okvan .AND. noncolin) CALL errore( 'lr_readin', 'Ultrasoft PP + noncolin is not fully implemented', 1 )
        IF (gamma_only)  CALL errore( 'lr_readin', 'gamma_only is not supported', 1 )
        !
        ! Tamm-Dancoff approximation is not recommended to be used with EELS, and
